@@ -6,6 +6,12 @@
 
 # pre-defined services
 
+try:
+    import pyinotify
+    watch = True
+except ImportError:
+    watch = False
+
 from service import ConfigurationServiceFactory as factory
 CentralConfigurationService = factory(watch=False)
-CentralConfigurationServiceSupervised = factory(watch=True)
+CentralConfigurationServiceSupervised = factory(watch=watch)
