@@ -90,6 +90,24 @@ class ConfigurationTests(TestCase):
         self.assertEqual(OL.get('cms.checkout_path'), '/bar')
         self.assertEqual(OL.get('cms.port'), 888)
 
+    def testWithMixCaseKeys(self):
+        parser = self._generateParser('model') 
+        # settings in -config2.ini must shadown the ones from -config.ini
+        parser.add_file(os.path.join(dirname, 'example-config3.ini'))
+        opts = parser.parse()
+        OL = OptionLookup(opts)
+        self.assertEqual(OL.get('cms.Path'), '/foo') 
+        self.assertEqual(OL.get('cms.CheckoutPath'), '/bar')
+
+    def testWithMixCaseKeys(self):
+        parser = self._generateParser('model') 
+        # settings in -config2.ini must shadown the ones from -config.ini
+        parser.add_file(os.path.join(dirname, 'example-config3.ini'))
+        opts = parser.parse()
+        OL = OptionLookup(opts)
+        self.assertEqual(OL.get('cms.MixedCaseParameter'), 99) 
+        self.assertEqual(OL.get('cms.Underscore_in_Parameter'), 'underscore') 
+
 
 class UtilTests(TestCase):
 
