@@ -14,6 +14,11 @@ class OptionNotSetMarker(object):
 
 DEFAULT_MARKER = OptionNotSetMarker
 
+class MyConfigParser(ConfigParser.RawConfigParser):
+    """ A config parser preserving lower-case spelling for keys """
+
+    def optionxform(self, s):
+        return s
 
 def generateParser(name, LOG=None, parser=None):
     """ Generate a configuration parser for all modules described.
@@ -52,7 +57,8 @@ def parseModel(filename, parser, LOG=None):
     if not os.path.exists(filename):
         raise IOError('Model file %s does not exist' % filename)
 
-    CP = ConfigParser.RawConfigParser()
+    CP = MyConfigParser()
+    CP.optionxfrom = str
     CP.read([filename])
     for section in CP.sections():
         if LOG:
@@ -92,6 +98,7 @@ class OptionLookup(object):
                 self.known_opts[k] = True
 
     def get(self, name, expand_env=False):
+
         if self.domain and not name.startswith(self.domain):
             name = '%s.%s' % (self.domain, name)
         try:
